@@ -53,9 +53,9 @@ REQUEST_QUEUE = {
         3: 'palp.sequence.sequence_memory.PrioritySequence',  # 本地：优先级队列（通过 request 的 level 指定，默认 level 10，越小越高）
     },
     2: {
-        1: 'palp.sequence.sequence_redis.FIFOSequence',  # redis：先进先出队列
-        2: 'palp.sequence.sequence_redis.LIFOSequence',  # redis：后进先出队列
-        3: 'palp.sequence.sequence_redis.PrioritySequence',  # redis：优先级队列（通过 request 的 level 指定，默认 level 10，越小越高）
+        1: 'palp.sequence.sequence_redis_request.FIFOSequence',  # redis：先进先出队列
+        2: 'palp.sequence.sequence_redis_request.LIFOSequence',  # redis：后进先出队列
+        3: 'palp.sequence.sequence_redis_request.PrioritySequence',  # redis：优先级队列（通过 request 的 level 指定，默认 level 10，越小越高）
     }
 }
 
