@@ -16,8 +16,8 @@ from palp.network.request import Request
 from palp.network.response import Response
 from palp.tool.short_module import import_module
 from palp.exception.exception_error import NotGeneratorFunctionError
-from palp.sequence.sequence_redis import FIFOSequence as FIFOSequenceRedis
 from palp.sequence.sequence_memory import FIFOSequence as FIFOSequenceMemory
+from palp.sequence.sequence_redis_item import FIFOSequence as FIFOSequenceRedis
 
 
 class BaseSpider(Thread):
